serodynamics: Modeling Longitudinal Antibody Responses to Infection
Source:R/serodynamics-package.R
serodynamics-package.RdImplements Bayesian hierarchical models for estimating antibody kinetic parameters from longitudinal serological data. Fits two-phase within-host models capturing antibody rise, peak, and decay following pathogen infection, using 'JAGS' for posterior inference. Designed as the upstream companion to the 'serocalculator' package for end-to-end seroepidemiologic analysis. Methods are described in Teunis et al. (2016) doi:10.1016/j.epidem.2016.04.001 and Teunis and van Eijkeren (2020) doi:10.1002/sim.8578 .
Author
Maintainer: Samuel Schildhauer sschildhauer@ucdavis.edu (ORCID)
Authors:
Samuel Schildhauer sschildhauer@ucdavis.edu (ORCID)
Peter Teunis p.teunis@emory.edu (ORCID) (Author of the method and original code.) [copyright holder]
Kwan Ho Lee ksjlee@ucdavis.edu (ORCID)
Kristen Aiemjoy kaiemjoy@ucdavis.edu (ORCID)
Douglas Ezra Morrison demorrison@ucdavis.edu (ORCID)